@@ -10,7 +10,7 @@ detectCores <- local({
       ## Get number of system cores from option, system environment,
       ## and finally detectCores().  This is also designed such that
       ## it is indeed possible to return NA_integer_.
-      value <- getOption2("future.availableCores.system", NULL)
+      value <- getOption2("parallelly.availableCores.system", NULL)
       if (!is.null(value)) {
         value <- as.integer(value)
         return(value)
